package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````0!4``#0```!<D0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````G'\`
M`)Q_```%`````!````$```#,C0``S(T``,R-``!X`@``I`(```8`````$```
M`@```-2-``#4C0``U(T``/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3,C0``S(T``,R-```T`@``-`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$P````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3````$T```!1````
M5@```%<```!>````7P```&``````````8@```&,`````````9````&4```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````"!`````````#``<```````"0`````````P`1``$`````
M`````````!(````)```````````````2````$```````````````$0```/0!
M`````````````!$```!]`0`````````````2````%P``````````````$@``
M`,T!`````````````!(````?```````````````2````)@``````````````
M$@````$"`````````````!(```#9`0`````````````2````+P``````````
M````(````!L#`````````````"$```!'```````````````2````30``````
M````````$@```%0``````````````!(```#2`@`````````````2````\`(`
M````````````$@```%L``````````````!(````S`@`````````````2````
M8@``````````````$@```+D"`````````````!(```!I```````````````2
M````<0``````````````$@```,L"`````````````!(```!Y````````````
M```2````H@(`````````````$@```($``````````````!(```"*````````
M```````@````X@(`````````````$@```*8``````````````!(```"K````
M```````````2````F@$`````````````%@```,`"`````````````!(```!@
M`@`````````````2````L@``````````````$@```%("`````````````!(`
M``!?`P`````````````2````&@,`````````````$0```(0"````````````
M`!(````'`P`````````````2````$@(`````````````$@```!P#````````
M`````!$```"Y```````````````2````P@``````````````$0```(L!````
M`````````!(```#4```````````````B````XP``````````````(````/D`
M`````````````!(```#_`@`````````````2````<`(`````````````$@``
M`/X``````````````"````"M`@`````````````2````&`$`````````````
M$@```+X!`````````````!(````=`0`````````````2````D@(`````````
M````$@```",!`````````````!(```"M`0`````````````2````,0$`````
M````````$@```$(!`````````````!(````N`@`````````````2````/P(`
M````````````$@```$@!`````````````!(```!Y`@`````````````2````
MZ0(`````````````$@```-H"`````````````!(```!7`0`````````````2
M````*0(`````````````$@```%X!`````````````!(```!E`0``````````
M```2````&0,`````````````(0```'8!`````````````!(```!?!```<)``
M```````0`!(`%`,``/@2``!(`@``$@`)`.X!``",/0``!````!(`"@"A`P``
ML"8``.0%```2``D`;P0``!`O``!8````$@`)`'X#``!,(```!````!(`"0`3
M!```"!````0````2``<`Q`,``)0L``!\`@``$@`)`!D$``!$D````````!``
M$@!'!```4"```#`"```2``D`_`,``$20````````$``2`(\#``#\)0``M```
M`!(`"0"N`P``.!X``%@````2``D`M@,``*PE```X````$@`)`-H#```8.P``
M/`$``!(`"0#O`P``@"(``"0````2``D`"`0``'"0````````$``2`&H$``!P
MD````````!``$@!$`P``9!4``&0````2``D`)P0``*0B``"8`0``$@`)`.4#
M``!`D```!````!$`$0!`!```1)`````````0`!$``00``$`5````````$@`)
M`!`$``#(.@``4````!(`"0!-`P``Y"4``!@````2``D`:`,``/@>``!4`0``
M$@`)`%0$``!4/```.`$``!(`"0!>!```<)`````````0`!(`,P0``#PD``!P
M`0``$@`)``!O<&5N9&ER`&UE;6-M<`!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`
M<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED
M`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!S=')R8VAR
M`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T
M<G-T<@!S=')C:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?
M9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E
M<G)N;U]L;V-A=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R
M;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4&5R
M;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!S=')C<'D`<F5A9&1I<@!S<')I;G1F`'-T<F1U<`!S=')T;VL`<'1H<F5A
M9%]A=&9O<FL`9G!R:6YT9@!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N
M`&QI8G!E<FPN<V\`;&EB8RYM=7-L+6%R;6AF+G-O+C$`7W-T87)T7V,`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP
M9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/
M3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?8G-S7W-T
M87)T`%]?96YD7U\`<VAA7VEN:70`7U]B<W-?<W1A<G1?7P!P87)?9&ER;F%M
M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`
M7U]B<W-?96YD7U\`7V5N9`!P87)?8VQE86YU<``O=7-R+VQI8B]P97)L-2]C
M;W)E7W!E<FPO0T]210````#,C0``%P```-"-```7````P(\``!<```#,CP``
M%P```-B/```7`````)```!<````0D```%P```!20```7````')```!<````@
MD```%P```"20```7````*)```!<````LD```%P```#20```7````.)```!<`
M``!`D```%P```,2/```5!0``R(\``!4&``#0CP``%0X``-2/```5'P``W(\`
M`!,C``#@CP``%2T``.2/```5+P``Z(\``!4Q``#LCP``%3(``/"/```5-@``
M](\``!4[``#XCP``%3T``/R/```500``T(X``!8#``#4C@``%@0``-B.```6
M!P``W(X``!8(``#@C@``%@D``.2.```6"@``Z(X``!8+``#LC@``%@P``/".
M```6#0``](X``!8.``#XC@``%A```/R.```6$0```(\``!82```$CP``%A,`
M``B/```6%```#(\``!85```0CP``%A8``!2/```6%P``&(\``!88```<CP``
M%AD``""/```6&@``)(\``!8;```HCP``%AP``"R/```6'0``,(\``!8>```T
MCP``%B```#B/```6(0``/(\``!8B``!`CP``%B0``$2/```6)0``2(\``!8F
M``!,CP``%B<``%"/```6*```5(\``!8J``!8CP``%BL``%R/```6+```8(\`
M`!8N``!DCP``%C```&B/```6,0``;(\``!8R``!PCP``%C,``'2/```6-```
M>(\``!8U``!\CP``%C<``("/```6.```A(\``!8Y``"(CP``%CH``(R/```6
M/```D(\``!8^``"4CP``%C\``)B/```60```G(\``!9"``"@CP``%D,``*2/
M```61```J(\``!9%``"LCP``%D8``+"/```61P``M(\``!9(``"XCP``%DD`
M`+R/```62P```4`MZ0%`O>@>_R_A!.`MY03@G^4.X(_@"/"^Y:!^````QH_B
M!\J,XJ#^O.4`QH_B!\J,XIC^O.4`QH_B!\J,XI#^O.4`QH_B!\J,XHC^O.4`
MQH_B!\J,XH#^O.4`QH_B!\J,XGC^O.4`QH_B!\J,XG#^O.4`QH_B!\J,XFC^
MO.4`QH_B!\J,XF#^O.4`QH_B!\J,XEC^O.4`QH_B!\J,XE#^O.4`QH_B!\J,
MXDC^O.4`QH_B!\J,XD#^O.4`QH_B!\J,XCC^O.4`QH_B!\J,XC#^O.4`QH_B
M!\J,XBC^O.4`QH_B!\J,XB#^O.4`QH_B!\J,XAC^O.4`QH_B!\J,XA#^O.4`
MQH_B!\J,X@C^O.4`QH_B!\J,X@#^O.4`QH_B!\J,XOC]O.4`QH_B!\J,XO#]
MO.4`QH_B!\J,XNC]O.4`QH_B!\J,XN#]O.4`QH_B!\J,XMC]O.4`QH_B!\J,
MXM#]O.4`QH_B!\J,XLC]O.4`QH_B!\J,XL#]O.4`QH_B!\J,XKC]O.4`QH_B
M!\J,XK#]O.4`QH_B!\J,XJC]O.4`QH_B!\J,XJ#]O.4`QH_B!\J,XIC]O.4`
MQH_B!\J,XI#]O.4`QH_B!\J,XHC]O.4`QH_B!\J,XH#]O.4`QH_B!\J,XGC]
MO.4`QH_B!\J,XG#]O.4`QH_B!\J,XFC]O.4`QH_B!\J,XF#]O.4`QH_B!\J,
MXEC]O.4`QH_B!\J,XE#]O.4`QH_B!\J,XDC]O.4`QH_B!\J,XD#]O.4`QH_B
M!\J,XCC]O.4`QH_B!\J,XC#]O.4`QH_B!\J,XBC]O.4`QH_B!\J,XB#]O.4`
MQH_B!\J,XAC]O.4`QH_B!\J,XA#]O.4`QH_B!\J,X@C]O.4`QH_B!\J,X@#]
MO.4`QH_B!\J,XOC\O.4`QH_B!\J,XO#\O.4`QH_B!\J,XNC\O.4`QH_B!\J,
MXN#\O.4`QH_B!\J,XMC\O.4`QH_B!\J,XM#\O.4`QH_B!\J,XLC\O.4P0"WI
M)-!-XAP`C>48$(WE%""-Y1@0C>(4((WB'`"-XMA!G^6P___KU#&?Y01`C^`#
M,)3G##"-Y<@QG^4,()WE`S"4YP(0H.$#`*#A$#"-Y6#__^NP,9_E`S"4YW!/
M'>X`4-/E``!5XPP``!J#___KF"&?Y0``4.,"((_@#`""Y0$``!H!`*#CH/__
MZZ[__^M\,9_E`S"?YP,PE.=[5\/E<#&?Y1P`G>4#,)_G`R"4YP-`@.+.,]+E
M!`"`X@,P@^,'`7#CSC/"Y0```)J`___K``&@X9;__^L\(9_E`#"@X0(@C^`$
M`(+E&""=Y1S`G>4`$)+E`!"`Y2`1G^4!$(_@!!"`Y1@1G^4!$(_@`!"1Y0@0
M@.4,$9_E`1"/X`P0H.4!$*#C`0!<X3```,H``%SC`Q",XA`0H-,!$:#!`""@
MX^10G^4!((/GX!"?Y0`@C>4%4(_@!""@X0P`E>4!$(_@-___ZP!`4.("```:
M#`"5Y6S__^L`0*#AM%"?Y050C^`,`)7E3/__ZZ@`G^4``(_@U```ZP``4.,,
M```:"#"5Y0``4^,#```:C`"?Y0``C^#,``#K"`"%Y8`PG^4#,(_@"`"3Y0``
M4.,````*D08`ZVPPG^4#,(_@#`"3Y7O__^O8_O_K!`"@X230C>(P@+WH`>&2
MYP$0@>($X*#ER/__ZIA[```X`0``-`$```0!``#H?```2'P``#1\``"`?```
MLBP``#A\``"9+```$'P``#0*``#D>P``,2H``,8I``"D>P``C'L```"PH.,`
MX*#C$!"?Y0$0C^`-`*#A#\#`XPS0H.$```#K@'@``!]`+>E(,)_E2""?Y0,P
MC^`"()/G"""-Y3P@G^4"()/G#""-Y0`@H.,$((WE+""?Y0(PD^<$((#B`#"-
MY0`0D.4(,)WE#`"=Y0/__^L4T(WB!/"=Y$QY```4`0``_`````@!```L`)_E
M+#"?Y0``C^`#,(_@``!3X2`PG^4#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3
M_R_A;'H``&AZ``#<>```$`$``#@`G^4X,)_E``"/X`,PC^``,$/@HQ^@X4,1
M@>`D,)_EP1"PX0,PC^`>_R\!&""?Y0(PD^<``%/C'O\O`1/_+^$H>@``)'H`
M`(QX```L`0``:#"?Y1!`+>D#,(_@`##3Y5Q`G^4``%/C!$"/X!"`O1A0,)_E
M`S"4YP``4^,"```*1#"?Y0,`G^?5_O_KRO__ZS@PG^4#,)3G``!3XP(```HL
M`)_E``"/X';^_^L!(*#C(#"?Y0,PC^``(,/E$("]Z-AY``!(>```)`$``&AY
M```,`0``X&@``'QY```T,)_E-""?Y0,PC^`",)/G``!3XP<```H00"WI(!"?
MY2``G^4!$(_@``"/X+C^_^L00+WHNO__ZKG__^K,=P``*`$``#1Y``"`:```
MG#"?Y?!'+>D`4%#B`S"/X`5`H`$@```*B""?Y0(PD^<`0)/E``!4XQL```H!
MD*#A!3"@X0-@H.$!(-/D``!2XST`4A/Z__\:!("@X05@1N`(<*#A!*"8Y```
M6N,*0*`!#0``"@8@H.$%$*#A"@"@X5O^_^L``%#C]/__&@8PVN<]`%/C\?__
M&@1P1^!'<:#A`6"&X@!PB>4&0(K@!`"@X?"'O>A\=P``'`$```=`+>E,()_E
M3#"?Y0(@C^`#,)+G#1"@X0`PD^4$,(WE`#"@X\K__^LP()_E*#"?Y0(@C^`#
M,)+G`""3Y00PG>4"(#/@`#"@XP````JK_O_K#-"-X@3PG>30=@``(`$``*QV
M``!S0"WID""?Y9`PG^4"((_@`S"2YP!`H.$`,)/E!#"-Y0`PH.,-8*#A=%"?
MY050C^`&$*#A!`"@X:S__^L``%#C"0``&EP@G^50,)_E`B"/X`,PDN<`()/E
M!#"=Y0(@,^``,*#C"@``"HO^_^LX,)_E`""=Y0,PE><`,)/E`C&#X`0@D^4`
M`%+C!""#Y/O__QKF___J"-"-XG"`O>AL=@``(`$``$QV```L=@``'`$``!!`
M+>F(()_EB#"?Y0(@C^"@T$WB`S"2YPT0H.$`0*#A`#"3Y9PPC>4`,*#C6?[_
MZP``4.,``*`3"0``&A`PG>4/.@/B"@I3XP$)4Q,$```:`A"@XP0`H.'$_?_K
M$`]OX:`"H.$P()_E*#"?Y0(@C^`#,)+G`""3Y9PPG>4"(#/@`#"@XP````I7
M_O_KH-"-XA"`O>B\=0``(`$``%QU``#P0RWI/"&?Y3PQG^4"((_@`S"2YZ30
M3>(`4%#B`#"3Y9PPC>4`,*#C$0``"@`PU>4``%/C#@``"I7]_^L`<%#B"P``
M"@2!G^4$D9_E"("/X`F0C^`'`*#AM/W_ZP!`4.(-```:!P"@X=']_^L%`*#A
M$?[_Z]P@G^7,,)_E`B"/X`,PDN<`()/EG#"=Y0(@,^``,*#C*0``"BO^_^L3
M0(3B"!"@X00`H.&=_?_K``!0X^?__PH)$*#A!`"@X9C]_^L``%#CXO__"@4`
MH.$;_O_K`&"@X00`H.$8_O_K``"&X`(`@.*@_?_K`&"@X6@0G^4$,*#A!2"@
MX0$0C^`&_O_K#1"@X08`H.'N_?_K`0!PXP8`H.$'```*$#"=Y0\Z`^(!"5/C
M`P``&K3__^L&`*#A[?W_Z\;__^J(_?_K^O__ZJ30C>+P@[WH''4``"`!``!!
M)```/"0``*QT``"7(P``\$<MZ3PAG^4\,9_E`=A-XAC03>("((_@`S"2YP$8
MC>(`,)/E%#"!Y0`PH.,",*#C`""@XP`PC>4`,*#C%!"!X@!PH.%8_?_K`0!0
MX@!@P>("(1;B<##_Y@0``%H!,%/B`SC@X2,XX.$!,)/B`B#"X-B0G^4#0%#@
MU("?Y0)@QN`)D(_@``!6XP``X+,`$*"Q'0``N@`PH.,$(*#A`#"-Y0R@C>(&
M,*#A!P"@X3[]_^L((*#A"A"@X0<`H.&@_?_K!P!0XPA00((%4(J``P``B@%(
M5.(`8,;BZ?__Z@%01>(*`%7A^?__.@@@H.,)$*#A!0"@X1']_^L``%#C]O__
M&@I01>`$`)7@Q1^FX$0@G^4T,)_E`B"/X`'(C>(#,)+G%,",X@`@D^4`,)SE
M`B`SX``PH.,````*J_W_ZP'8C>(8T(WB\(>]Z+1S```@`0``B'0```@``0"T
M<@``\$\MZ0%0H.'`(9_EP#&?Y0(@C^`#,)+G%-!-X@`PD^4,,(WE`#"@XP`P
MT>4`8*#A/0!3XP%0@0(%`*#AD/W_ZP@0C>(`<*#A!@"@X:3^_^N`D9_E`$!0
MX@F0C^`1```*A_W_ZP``5^$F``"*`4!$X@$PU>0``%/C`3#DY?O__QI4(9_E
M2#&?Y0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XT@```IY_?_K,#&?Y0.@F><`
ML)KE!#&;YP``4^,R```:'#&?Y0*`A.(#,(_@`""3Y0B!H.$``%+C+0``"@@0
MH.$+`*#AQ/S_ZP``4.,``(KEXO__"@`@H.,`,)KE"$"-Y0@P@^`$(`/E!C"@
MX0,`H.$!(-/D``!2XST`4A/Z__\:N#"?Y0)PA^(#0)GG!@!`X```A^`(@)WE
M`)"4Y=O\_^L``%#C"`&)Y\S__PH`,)3E""&3YP$0UN0",*#A/0!1XP``41,`
M$,+E`2""XOC__QH](*#C`"##Y0$@U>0``%+C`2#CY?O__QJ\___J`4"$XL?_
M_^H!(*#C"`"@X0`@@^7"_/_K`#!0X@0PC>6S__\*"Q"@X0@@2.*__/_K!#"=
MY0`PBN7*___J%-"-XO"/O>A<<@``(`$``!1R``#D<0``'`$``$!S``!PSQWN
M.#"?Y3@@G^4#,(_@`C"3YPC03>(L`)_E!#"-Y0``G^<D,)_E)!"?Y00@G>4`
M`)SG`S"/X`$0C^`(T(WB!OW_ZGAP```P`0``?'$``(-@``"Y'P``$T`MZ7!/
M'>Y$,)_E`S"?YP,`E.?C___K`""@XS0PG^4T`)_E`S"/X```G^<L$)_E!""-
MY2@@G^4`,(WE``"4YP(@C^`!$(_@9_S_ZPC0C>(0@+WH.'$``/$A```<<0``
M<1\``+P-``!P0"WI,"&?Y3`QG^4"VDWB&-!-X@(@C^`#,)+G`AJ-XA00@>(`
M,)/E`#"!Y0`PH.-?_/_K""&?Y0AAG^4"((_@`""-Y0`AG^4,0(WB`#"@X080
MH.$$`*#A`B"/X$7\_^L!,(#B!@!3X0```)KP`/#G`0!PXPP``!H`,*#CS!"?
MY;@@G^4!$(_@`@J-X@(@D><4`(#B`!"2Y0`@D.4!$#+@`""@XR````K._/_K
M`5J-XA!0A>($`*#A`2J@XP40H.&&_/_K`$!0XNK__[H!`(3B3/S_ZP`P4.+F
M__\*!0!3X0(``"H$((/@`@!5X=[__SH%`%/A`@``F@0@A>`"`%/AV?__.@8`
M5.'7___*!""@X0,`H.$%$*#AJ?S_ZP`@H.,`,*#A!"#`Y]/__^H#`*#A`MJ-
MXAC0C>)P@+WHL&\``"`!```R'P```1````H?``!`;P``J?__ZO!/+>GX(9_E
M^#&?Y4+=3>("((_@+-!-X@!0H.'H`9_E`S"2YP%`H.%"'8WB``"/X"00@>(`
M,)/E`#"!Y0`PH./2_?_K+Q"@XP!@H.$%`*#A.OS_ZP``4.,/```*K`&?Y040
MH.$``(_@Y/[_ZZ`AG^60,9_E`B"/X$(=C>(#,)+G)!"!X@`@D^4`,)'E`B`S
MX``PH.-6```*?/S_ZP0`H.$7_/_K;!&?Y6QQG^4!$(_@9_S_ZP!`H.%@@9_E
M8)&?Y0=PC^`(@(_@"9"/X```5./A__\*`##4Y0``4^,'0*`!``!6XP0```H$
M$*#A!@"@X=S[_^L``%#C-P``"@0`H.%?_/_K`!"@XP$P0.(#,(3@`P!4X0(`
M`"H`(-/E+P!2XQ4```H$`*#A5?S_ZP"@H.$%`*#A4OS_ZP"@BN`!H(KB`0I:
MX\3__RJHL(WB!*!+X@0PH.$((*#A`1J@XPH`H.$$4(WE`)"-Y:S[_^L!`(#B
M`0I0XP(``)KP`/#G`1!#Y.+__^H*`*#A"!"-XA[\_^L``%#C$```&I`P&^4/
M.@/B`@E3XPP``!H!$*#C"@"@X9?[_^L``%#C!P``&F0`G^4*$*#A``"/X(S^
M_^L*`*#AR_O_ZP!0H.&C___J2!"?Y0``H.,!$(_@&?S_ZP!`H.&U___J!0"@
MX4+=C>(LT(WB\(^]Z%QN```@`0``[AT``+\=``#X;0``A!T``!$=```Z'@``
M:AT``%\<``!,'```$$`MZ2\0H.,`0*#AI_O_ZP``4.,!0(`2!`"@X1!`O>BK
M^__J,$`MZ7`AG^5P,9_E`=I-X@(@C^`,T$WB`1J-X@,PDN<`4%#B!!"!X@`P
MD^4`,('E`#"@XP(```H`,-7E``!3XQ$``!HX(9_E,#&?Y0(@C^`!&HWB`S"2
MYP00@>(`()/E`#"1Y0(@,^``,*#C````"O'[_^L,`9_E``"/X`':C>(,T(WB
M,$"]Z(C[_^KG^__K`0"`X@$*4.,U``"*!$"-X@40H.$$`*#A=/O_ZP0`H.'>
M^__K`""@XP$`0.(``(3@!`!0X0(``)H`,-#E+P!3XQ(```HO$*#C!`"@X6K[
M_^L``%#C#P``&IP@G^6,,)_E`B"/X`$:C>(#,)+G!!"!X@`@D^4`,)'E`B`S
MX``PH./6__\:=`"?Y0``C^#6___J`2!`Y.7__^H$`%#A`#"@@P`PP(4$`*#A
M7/O_ZU`@G^4X,)_E`B"/X`$:C>(#,)+G!!"!X@`@D^4`,)'E`B`SX``PH./!
M__\:`=J-X@S0C>(P@+WH``"@X^___^H(;```(`$``,QK```%&P``*&L``&4:
M``#4:@``&`&?Y1!`+>D``(_@_?S_ZPP!G^4,09_E``"/X/G\_^L$`9_E!$"/
MX```C^#U_/_K^`"?Y0``C^#R_/_K\`"?Y0``C^#O_/_KZ`"?Y0``C^#L_/_K
MX`"?Y0``C^#I_/_KV`"?Y0``C^#F_/_K!`"@X>3\_^O(`)_E``"/X.'\_^O`
M`)_E``"/X-[\_^NX`)_E``"/X,+\_^L`$%#B`0``"@0`H.':_?_KH`"?Y0``
MC^"[_/_K`!!0X@(```J0`)_E``"/X-+]_^N(`)_E``"/X+/\_^L`$%#B"```
M"G@`G^4``(_@ROW_ZQ!`O>AL$)_E;`"?Y0$0C^```(_@Q/W_ZF``G^4``(_@
MI?S_ZP`04.+T__\*4`"?Y0``C^#P___J0!H``#D:``!K&@``,1H``"X:```I
M&@``+1H``-89```A&@``(1H``+,9```3&@``"!H```8:```%&@``3AD``/X9
M``!Q&0``W1D``&T9```L`)_E$$`MZ0``C^"(_/_K``!0XQ"`O0@``-#E``!0
MXS``4!,!`*`#``"@$P$`(.(0@+WH#1D``!!`+>D_^__K[?K_ZP``4.,``)`5
M$("]Z/=`+>F8<)_E`$"@X0=PC^`'`*#A<OS_ZP!04.($$*#A`@``"@`PU>4`
M`%/C!```&G``G^4``(_@#-"-XO!`O>B#_?_JR?K_ZP``4.,2```:!`"@X1_[
M_^L`8*#A!0"@X1S[_^L``(;@`@"`XJ3Z_^L`8*#A,#"?Y3`0G^4$(*#A`1"/
MX`!0C>4#,(_@"/O_ZP80H.$'`*#AYO__Z@S0C>+P@+WH*!D````9``#\%P``
MTA@``/!'+>E<)9_E7#6?Y0(@C^!8Q9_E`S"2YQ'>3>(,P(_@`#"3Y0PQC>4`
M,*#C##",XAA`C.*H4(WBP."-X@!@H.$'`)/H!P"%Z`\`M.@/`*[H`P"4Z##`
MC.*T@(WB`P".Z`<`G.@'`(CH!`6?Y01UG^4``(_@+?S_ZP!`4.('<(_@$0``
M"@`PU.4``%/C#@``"JW__^O@))_ES#2?Y0(@C^`#,)+G`""3Y0PQG>4"(#/@
M`#"@XP````K<^O_K!`"@X1'>C>+P1[WH=?K_ZIC__^L`0%#B!```&@0`F.0`
M`%#C3@``&I1$G^4$0(_@!`"@X<OZ_^N``*#A`0"`XE/Z_^L`@*#A`)"@X72D
MG^4!0$3B"J"/X`$@].4``%+C1P``&L"0C>($0)GD``!4XT@``!H``%3C!0``
M&@20E>0``%GC5P``"@`PV>4``%/C3@``&@0`H.&R^O_K`)"@X0@`H.&O^O_K
M`)")X`&;B>($D(GB"0"@X37Z_^L`4*#A!#2?Y004G^4#,(_@`#"-Y?PSG^4$
M(*#A`S"/X`$0C^`$@(WEEOK_ZP<=H.,%`*#AA/K_ZP$`<.,\```:?OK_ZP`P
MD.41`%/C.```"L0CG^7$$Y_E`@"7YP`PC>4`();E!3"@X0``D.4!$(_@7?K_
MZP!`H..D(Y_E<#.?Y0(@C^`#,)+G`""3Y0PQG>4"(#/@`#"@XZC__QH$`*#A
M$=Z-XO"'O>C"^__K`#!0XJK__PH`,-/E``!3XZ?__PH9^O_KH___Z@D`H.$*
M$*#A;/K_ZP*0B>*O___J!`"@X;3[_^L`0%#BK___"@`PU.4``%/CK/__"O/[
M_^L``%#CJ?__"@0`H.$'^O_K`$"@X:C__^H)`*#AZ_O_ZP``4..F__\*"0"@
MX?;__^H)0*#AJ/__Z@4`H.$0$(WB2/K_ZP"`4.(#```:(#"=Y0\Z`^(!"5/C
M"```"KPRG^7$$I_E`P"7YP`@EN4%,*#A`1"/X```D.4<^O_KO?__ZBA`G>5/
M^O_K``!4X?+__QH@,)WE@SN@X:,[H.$'#5/C[?__&@D`H.'+^?_K`$"@X7@"
MG^4``(_@?_O_ZP`04.)=```:`'"6Y0<`H.$W^O_K`P!0XP"0H.$:``":4!*?
MY00`0.(!$(_@``"'X*CY_^L``%#C$P``&@0`6>,#```*"9"'X`4P6>4O`%/C
M#0``&@1@EN4``%;C"@``"@8`H.$B^O_K`P!0XP8``)H$$I_E!`!`X@$0C^``
M`(;@E/G_ZP``4.,&<*`!SO[_ZP"04.(^```:!P"@X0D0H.&V^?_K`'!0XCD`
M``H8_/_K`*!1X@!@H.$U``"Z"B!0X@`PRN(`D(WE!P"@X=B0C>)Z^?_K"1"@
MX08@H.,'`*#AW/G_ZY01G^4)`*#A`1"/X`8@H.,*$('B5?G_ZP"04.(C```:
M,B!6X@`PRN+@8(WB!P"@X0"0C>5H^?_K*""@XP80H.$'`*#AROG_ZU`QG^50
M$9_E`S"/X`0PC>5(,9_E!2"@X00`H.$`8(WE`S"/X`$0C^`(D<WEW/G_ZP4`
MH.'.^?_K)`&?Y000H.$``(_@/OS_ZP0`H.&G_O_K3___Z@``EN4Y_?_K`'!0
MXI[__QJ<___J^!"?Y?@`G^4!$(_@``"/X#'\_^M'^?_KZ#"?Y>@0G^4#,(_@
M"0"-Z.`PG^4%(*#A!`"@X0,PC^`!$(_@OOG_Z\Q@G^7,<)_ES)"?Y09@C^`'
M<(_@"9"/X`<=H.,$`*#AIOG_ZP$`<./6__\:H/G_ZP`PD.41`%/CTO__&BWY
M_^L!@(CB``"-Y08PH.$%(*#A!Q"@X00`H.'T@,WAIOG_Z^S__^H`:```(`$`
M`#!I``!*%P``D&<``'!G``"H%P``AQ<``"$7```$%P``/A8````!``#&%@``
M%&8```$6``!C%0``X!4``)45```C5```D14``,(4``!6$P``'A,``+(3``!!
M$P``$14``%44``#:$@``PA(``$L4``#=%```<$`MZ7!/'>X0,I_E$`*?Y0,P
MG^<``(_@`S"4YV0@T^5E(,/ER/K_ZP``4.,%```*`##0Y3$`4^,"```:`3#0
MY0``4^,````*UOW_Z]0!G^74$9_E``"?YP,PH.,!(*#C``"4YP$0C^`@^?_K
M`%!0XA````JT,9_E#!"5Y0,PG^>L(9_E`!"1Y0,`E.<"((_@'/G_ZPPPE>4`
M$)/E"#"1Y0$%$^,#```*B#&?Y0,PG^<#`)3GYOC_ZWP!G^5\$9_E``"?YP,P
MH.,!(*#C``"4YP$0C^`%^?_K`&!0XA<```I<`9_E``"/X)?Z_^L`(%#B!@``
M"DPQG^4,$);E`S"?YP`0D>4#`)3G_OC_ZPL``.I3_/_K`%!0X@P0EN4I```*
M)#&?Y04@H.$#,)_G`!"1Y0,`E.?S^/_K!0"@X2KY_^L(,9_E"!&?Y0,PG^<!
M(*#C`U"4YP$0C^`%`*#AF/C_Z_`@G^4`$*#A`B"/X`4`H.'D^/_K`""@X]PP
MG^7<`)_E`S"?YP``C^`#,)3GT$"?Y64@P^5L^O_K!$"/X```4.,(`(3E#@``
M&@0`E.4:_O_K``!0XP@`A.4)```:I`"?Y0``C^"*^/_KG#"?Y0,PC^`$()/E
ME#"?Y0`@DN4#,)_GQO__ZHA`G^4'':#C!$"/X`@`E.7Y^/_K`2"`XA$`4.,!
M`%(3`#"@X7"`O9AD`)_E!@"4Z0``C^``$)'E=/C_ZS!C``#]$0``[&(``"@3
M``#$8@```A,``)1B``"`8@``PQ(``/L0``!$8@``&&(``/AA``!!$@``0A(`
M`,!A``!2$```+&(``/`1``#X80``9&$``-AA``"]$0``<$`MZ0!`H.'A_/_K
MU_S_ZP!0H.&@_?_K``!0XP``5!-P@+T(`##4Y0``4^-P@+T('!"?Y04`H.$!
M$(_@AOC_ZP``5>%P@+T8!`"@X7!`O>B+^O_J#1```/!/+>DX*Y_E.#N?Y0(@
MC^!3WTWB`S"2YP0@C>("P*#A`#"3Y40QC>4`,*#C7."`XAPP@.($$)/D,1^_
MY@,`7N$$$(SD^O__&A#`H.,"$*#A(."1Y30PD>4!P(SB#C`CX`C@D>4`$)'E
M#C`CX`$P(^`$((+BXS^@X5``7.,\,(+E\?__&L`ZG^4$D)WE$&"0Y=A`P.$#
MD(G@!2`DX(!`D.@&D(G@#B`"X`4@(N#GG8G@`I")X`@@G>5N$23@!Q`!X`,@
M@N`%((+@!!`AX&?!H.$"$('@#""=Y6Z!+.`)@`C@`R""X`0@@N`0H)WE;H$H
MX.D=@>`"@(C@:2$LX`$@`N`#H(K@X8V(X&ZABN!A$:#A%+"=Y0P@(N`*((+@
M::$AX`.PB^`(H`K@#,"+X&FA*N`8L)WEZ"V"X`R@BN!HP2'@`["+X`+`#.#B
MK8K@:9&+X&(AH.$<L)WE`<`LX`G`C.!HD2+@`["+X`J0">`!$(O@:)$IX""P
MG>7JS8S@`9")X&H1(N`#L(O@#!`!X.R=B>!H@8O@;,&@X22PG>4"$"'@"!"!
MX&J!+.`#L(O@"8`(X`(@B^!J@2C@*+"=Y>D=@>`"@(C@:2$LX`.PB^`!(`+@
MX8V(X&JAB^!A$:#A++"=Y0P@(N`*((+@::$AX`.PB^`(H`K@#,"+X&FA*N`P
ML)WEZ"V"X`R@BN!HP2'@`["+X`+`#.#BK8K@:9&+X&(AH.$TL)WE`<`LX`G`
MC.!HD2+@`["+X`J0">`!$(O@:)$IX#BPG>7JS8S@`9")X&H1(N`#L(O@#!`!
MX.R=B>!H@8O@;,&@X3RPG>4"$"'@"!"!X&J!+.`#L(O@"8`(X`(@B^!J@2C@
M0+"=Y>D=@>`"@(C@:2$LX`.PB^`!(`+@X8V(X&JAB^!A$:#A1+"=Y0P@(N`*
M((+@::$AX`.PB^`(H`K@#,"+X&FA*N!(L)WEZ"V"X`R@BN!HP2'@`["+X`+`
M#.#BK8K@:9&+X&(AH.%,L)WE`<`LX`G`C.!HD2+@`["+X`J0">`!$(O@:)$I
MX`&0B>!0$)WEZLV,X&JQ(N`,L`O@`S"!X&@Q@^`"L"O@5("=Y0.PB^`4.)_E
M[)V)X&P1H.$#@(C@6,"=Y0*`B.!J(2'@"2`BX`/`C.#IO8O@`H"(X&K!C.!I
M(2'@7*"=Y0L@(N`"P(S@`Z"*X&LAH.'KC8C@`:"*X&D1(N`($"'@`:"*X&`0
MG>7HS8S@`Q"!X&D1@>!HD2+@#)`IX`D0@>!DD)WE[*V*X`.0B>!LP:#A`I")
MX&@A+.`*("+@`I")X&@@G>7J'8'@`R""X&@A@N!J@2S@`8`HX`@@@N!L@)WE
MX9V)X`.`B.!A$:#A#("(X&K!(>`)P"S@#("(X'#`G>7I+8+@`\",X&K!C.!I
MH2'@`J`JX`K`C.!TH)WEXHV(X`.@BN!B(:#A`:"*X&D1(N`($"'@`:"*X'@0
MG>7HS8S@`Q"!X&D1@>!HD2+@#)`IX`D0@>!\D)WE[*V*X`.0B>!LP:#A`I")
MX&@A+.`*("+@`I")X(`@G>7J'8'@`R""X&@A@N!J@2S@`8`HX`@@@N"$@)WE
MX9V)X`.`B.!A$:#A#("(X&K!(>`)P"S@#("(X(C`G>7I+8+@`\",X&K!C.!I
MH2'@`J`JX`K`C.",H)WEXHV(X`.@BN!B(:#A`:"*X&D1(N`($"'@`:"*X)`0
MG>7HS8S@`Q"!X&D1@>!HD2+@#)`IX`D0@>"4D)WE[*V*X`.0B>!LP:#A`I")
MX&@A+.`*("+@`I")X)@@G>7J'8'@`R""X&@A@N!J@2S@`8`HX`@@@N"<@)WE
MX9V)X`.`B.!A$:#A#("(X&K!(>`)P"S@#("(X*#`G>7I+8+@`\",X&DQ(>#B
MC8C@`C`CX&(AH.%JP8S@::&"X0/`C.`(H`K@:3$"X*2PG>4#H(KAI#6?Y>C-
MC.`#L(O@`1"+X`&@BN!H$8+A:+$"X`P0`>`+$('AJ+"=Y>RMBN`#L(O@;,&@
MX6F1B^`)$('@:)&,X6BQ#.`*D`G@"Y")X:RPG>7J'8'@`["+X`(@B^`"D(G@
M:B&,X6JQ#.`!(`+@"R""X;"PG>7AG8G@`["+X&$1H.%H@8O@""""X&J!@>%J
ML0'@"8`(X`N`B.&TL)WEZ2V"X`.PB^`,P(O@#("(X&G!@>%IL0'@`L`,X`O`
MC.&XL)WEXHV(X`.PB^!B(:#A:J&+X`K`C.!IH8+A:;$"X`B@"N`+H(KAO+"=
MY>C-C.`#L(O@`1"+X`&@BN!H$8+A:+$"X`P0`>`+$('AP+"=Y>RMBN`#L(O@
M;,&@X6F1B^`)$('@:)&,X6BQ#.`*D`G@"Y")X<2PG>7J'8'@`["+X`(@B^`"
MD(G@:B&,X6JQ#.`!(`+@"R""X<BPG>7AG8G@`["+X&$1H.%H@8O@""""X&J!
M@>%JL0'@"8`(X`N`B.',L)WEZ2V"X`.PB^`,P(O@#("(X&G!@>%IL0'@`L`,
MX`O`C.'0L)WEXHV(X`.PB^!B(:#A:J&+X`K`C.!IH8+A:;$"X`B@"N`+H(KA
MU+"=Y>C-C.`#L(O@`1"+X`&@BN!H$8+A:+$"X`P0`>`+$('AV+"=Y>RMBN`#
ML(O@;,&@X6F1B^`)$('@:)&,X6BQ#.`*D`G@"Y")X=RPG>7J'8'@`["+X`(@
MB^`"D(G@:B&,X6JQ#.`!(`+@"R""X>"PG>7AG8G@`["+X&$1H.%H@8O@:K&!
MX0@@@N`)L`O@:H$!X`BPB^'D@)WEZ2V"X`.`B.`,P(C@:8&!X0RPB^`"@`C@
M:<$!X`R`B.'HP)WEXKV+X`/`C.!B(:#A:L&,X&FA@N$,@(C@"Z`*X&G!`N`,
MH(KA[,"=Y>N-B.`#P(S@`1",X&O!@N$!H(K@",`,X&L1`N`!P(SA\!"=Y>BM
MBN`#,('@:3&#X`/`C.#T$)WEP#*?Y6B!H.$#$('@`B"!X&L1*.`*$"'@`2""
MX/@0G>7JS8S@:I$HX`,0@>`,D"G@:Q&!X`D0@>#\D)WE["V"X`.0B>!LP:#A
M")")X&J!+.`"@"C@")")X`"!G>7B'8'@`X"(X&J!B.!BH2S@`:`JX`J`B.`$
MH9WEX9V)X`.@BN!A$:#A#*"*X&+!(>`)P"S@#*"*X`C!G>7IC8C@`\",X&+!
MC.!I(2'@""`BX.BMBN`"P(S@:"&@X0R!G>44L9WE`X"(X`&`B.!I$2+@"A`A
MX`&`B.`0$9WEZLV,X`,0@>!I$8'@:I$BX.R-B.`,D"G@`["+X&S!H.$"L(O@
M:B$LX`@@(N`"L(O@&"&=Y0D0@>#H'8'@:)$LX`,@@N`!D"G@:B&"X`D@@N`<
MD9WEX;V+X`.0B>!A$:#A#)")X&C!(>`+P"S@#)")X"#!G>4DH9WE`\",X.LM
M@N!HP8S@:X$AX.*=B>`"@"C@`Z"*X&(AH.$!H(K@:Q$BX`D0(>`!H(K@*!&=
MY0C`C.#IS8S@:8$BX`,0@>`,@"C@:Q&!X`@0@>`L@9WE[*V*X`.`B.!LP:#A
M`H"(X&DA+.`*("+@`H"(X#`AG>7J'8'@`R""X&DA@N!JD2S@`9`IX`D@@N`T
MD9WEX8V(X`.0B>!A$:#A#,")X&J1(>`(D"G@"<",X#B1G>7H+8+@`Y")X&J1
MB>!HH2'@`J`JX`J0B>`\H9WEXLV,X`.@BN!B(:#A`1"*X&BA(N`,H"K@"A"!
MX$"AG>7LG8G@`S"*X`<P@^!L<2+@:#&#X`EP)^#I'8'@!S"#X.$]@^`"8(;@
M8""?Y0`P@.4!X([@0#"?Y6E!A.!L487@`B"/X`3@@.4(0(#E#%"`Y1!@@.4#
M,)+G`""3Y40QG>4"(#/@`#"@XP````H.]O_K4]^-XO"/O>A(7P``(`$``)EY
M@EJAZ]ENW+P;C];!8LI(5```$$`MZ6``H..*]?_K*!"?Y2@@G^4HP)_E*."?
MY090@.@D()_E$""`Y0`@H.,4((#E&""`Y5P@@.40@+WH`2-%9XFKS>_^W+J8
M=E0R$/#ATL/P02WI`F"@X0!0H.$4,)#E@B&@X0(PD^`8()`E%#"`Y0$@@B(8
M((`E&#"0Y0%`H.&F/H/@&#"`Y5P`D.4<@(7B``!0XQD```I`<&#B!@!7X0``
MB.`&<*"A`0!0X0,``"H',(#@`P!1X00``"KP`/#G!S"!X`$``)H#`%#A^?__
MZ@<@H.$$$*#AQ?7_ZUPPE>4#,(?@0`!3XUPPA>7P@;T8!0"@X0=@1N`'0(3@
MY_S_ZUQPA>(_`%;C"@``R@@`5.$9``":!C"(X`,`5.'F__\Z!B"@X000H.$(
M`*#AL/7_ZUQ@A>7P@;WH"`!4X4`PA.(*``":!P!4X=O__SH((*#A!!"4Y`,`
M5.$$$(+D^___&@4`H.%`8$;BS/S_Z^3__^KU__\J`P!8X?+__^KG__\J!C"$
MX`,`6.'C___J\$$MZ1R`@>(4,)'E&&"1Y0%`H.%_$.#C,W^_YJ,QH.$_,`/B
M`2"#XC@`4N,`4*#A`Q#(YP(`B.``$*#3-F^_YC@@8M('``#:`!"@XT`@8N(,
M]?_K!`"@X:W\_^LX(*#C`!"@XP@`H.$&]?_K!`"@X?1EQ.&F_/_K`S#4Y00`
MH.$`,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0<PU.4$,,7EMC#4
MX04PQ>4$,)3E(S2@X08PQ>4$,)3E!S#%Y0LPU.4(,,7ENC#4X0DPQ>4(,)3E
M(S2@X0HPQ>4(,)3E"S#%Y0\PU.4,,,7EOC#4X0TPQ>4,,)3E(S2@X0XPQ>4,
M,)3E#S#%Y1,PU.40,,7ELC'4X1$PQ>40,)3E(S2@X1(PQ>40,)3E$S#%Y?!!
MO>@\]?_J`4`MZ0%`O>@>_R_A/0```$`````+````0````!````!`````)@``
M`$`````U````0`````,```!`````!@```$`````4````0`````X```!`````
M#0```$`````E````0````!(```!`````*````$`````"````0````!@```!`
M````"0```$`````*````0```````````````+BX`)7,O)7,`1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C
M+R5I+R5S`&5X90!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"
M`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?
M4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/
M0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!,1%],24)205)97U!!5$@`
M4UE35$5-`"4P,G@`)7,E<R5S)7,`<&%R+0`E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"5S.B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO
M=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R;``N<&%R`"5S
M)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`8
M`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U-P!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE
M`"TM`%5315(`55-%4DY!344`5$5-4$1)4@!435``+W1M<`!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?
M<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)
M3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE
M7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U
M8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*
M;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE
M.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S
M:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E
M860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#
M*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@
M,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,
M051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L
M"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP
M(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR
M9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F
M:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M
M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS
M>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q
M6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D[
M"F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI
M.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!
M1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@
M*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG
M="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@
M)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]
M"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M
M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I
M;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA
M9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F
M+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F
M("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F
M;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D
M8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I
M>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F
M<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@
M,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q
M=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)
M0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR
M971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL
M97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F
M:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I
M('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN
M(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F
M('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R
M(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!
M1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W
M+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*
M)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII
M9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(
M+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@
M(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@
M9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@
M(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M
M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*
M96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M
M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N
M*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I
M9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;
M4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC
M;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ
M<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=
M.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%
M04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*
M)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE
M("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*
M;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M
M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O
M=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P
M96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A
M<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I
M;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ
M<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN
M+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X
M=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T
M:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[
M4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@
M>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O
M<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M
M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(
M12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!
M0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A
M8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@
M(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I
M<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH
M;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D
M8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE
M?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E
M;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN
M9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE
M(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[
M7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E
M;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,
M3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*`'!E<FQX<VDN8P``0T%#2$4`/0```$`````+````0```
M`!````!`````)@```$`````U````0`````,```!`````!@```$`````4````
M0`````X```!`````#0```$`````E````0````!(```!`````*````$`````"
M````0````!@```!`````"0```$`````*````0```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````Z!8``%P6```!````)`,`
M``$````O`P``#P```'L$```,````"!````T```",/0``&0```,R-```;````
M!````!H```#0C0``'`````0```#U_O]O+`$```4```"D"```!@```!0"```*
M````F00```L````0````%0`````````#````Q(X```(```#@`0``%````!$`
M```7````*`X``!$```!`#0``$@```.@````3````"````!@`````````^___
M;P$```CZ__]O$```````````````````````````````````````````````
M``````````#4C0`````````````4$```%!```!00```4$```%!```!00```4
M$```%!```!00```4$```%!```!00```4$```%!```!00```4$```%!```!00
M```4$```%!```!00```4$```%!```!00```4$```%!```!00```4$```%!``
M`!00```4$```%!```!00```4$```%!```!00```4$```%!```!00```4$```
M%!```!00```4$```%!```!00```4$```%!```!00```4$```%!```!00```4
M$```%!```!00```4$```%!```!00```4$```%!```!00``#X$@``````````
M``",/0`````````````($```````````````````````````````````````
M`````````````)````I005(N<&T*`````,Y````I/@````````H_```#/P``
MPD```"`_``#*0````````+1```"Y0````````--```!'0T,Z("A!;'!I;F4@
M,3(N,BXQ7V=I=#(P,C(P.3(T+7(Q,"D@,3(N,BXQ(#(P,C(P.3(T`$$R````
M865A8FD``2@````%-EI+``8'"`$)`0H"$@03`10!%0$7`Q@!&@(<`1X$(@%$
M`0`N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG
M;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````
M``````````````````````````````````````````````````L````!````
M`@```!0!```4`0``&````````````````0`````````3````]O__;P(````L
M`0``+`$``.@````#``````````0````$````'0````L````"````%`(``!0"
M``"0!@``!`````,````$````$````"4````#`````@```*0(``"D"```F00`
M`````````````0`````````M````"0````(```!`#0``0`T``.@````#````
M``````0````(````-@````D```!"````*`X``"@.``#@`0```P```!`````$
M````"````#\````!````!@````@0```($```#```````````````!```````
M```Z`````0````8````4$```%!```.0"``````````````0````$````10``
M``$````&````^!(``/@2``"4*@`````````````$`````````$L````!````
M!@```(P]``",/0``#```````````````!`````````!1`````0````(```"8
M/0``F#T```!"``````````````0`````````60````$````"````F'\``)A_
M```$```````````````$`````````&,````.`````P```,R-``#,C0``!```
M````````````!`````0```!O````#P````,```#0C0``T(T```0`````````
M``````0````$````>P````8````#````U(T``-2-``#P````!``````````$
M````"````(0````!`````P```,2.``#$C@``/`$`````````````!`````0`
M``")`````0````,`````D````)```$0```````````````0`````````CP``
M``@````#````1)```$20```L```````````````$`````````)0````!````
M,`````````!$D```-0```````````````0````$```"=`````P``<```````
M````>9```#,```````````````$``````````0````,``````````````*R0
6``"M```````````````!````````````
